@@ -40,12 +40,12 @@ def resolveEqSecondDegree(equation):
     The given equation should be in the from of ax²+bx+c=0. 
     """
     eq = equation.replace(" ","")
-    posXSquare = eq.find('x²')
+    posSquare = eq.find('²')
     posX = eq.find('x')
     posEqual = eq.find('=')
 
-    a = int(eq[0:posXSquare])
-    b = int(eq[posXSquare+2:posX])
+    a = int(eq[0:posSquare-1])
+    b = int(eq[posSquare+1:posX])
     c = int(eq[posX+1:posEqual])
 
     solution = []
